@@ -50,6 +50,7 @@ test_that("tableCharacteristics", {
   )
 
   cdm <- mockCohortCharacteristics(
+    con = connection(), writeSchema = writeSchema(),
     dus_cohort = dus_cohort, person = person,
     comorbidities = comorbidities, medication = medication,
     observation_period = observation_period
@@ -121,142 +122,145 @@ test_that("tableCharacteristics", {
 
 test_that("tableCohortOverlap", {
   skip_on_cran()
-  person <- dplyr::tibble(
-    person_id = 1:20,
-    gender_concept_id = 8532,
-    year_of_birth = runif(n = 20, min = 1950, max = 2000),
-    month_of_birth = runif(n = 20, min = 1, max = 12),
-    day_of_birth = runif(n = 20, min = 1, max = 28),
-    race_concept_id = 0,
-    ethnicity_concept_id = 0
-  )
-
-  table <- dplyr::tibble(
-    cohort_definition_id = c(rep(1, 15), rep(2, 10), rep(3, 15), rep(4, 5)),
-    subject_id = c(
-      20, 5, 10, 12, 4, 15, 2, 1, 5, 10, 5, 8, 13, 4, 10,
-      6, 18, 5, 1, 20, 14, 13, 8, 17, 3,
-      16, 15, 20, 17, 3, 14, 6, 11, 8, 7, 20, 19, 5, 2, 18,
-      5, 12, 3, 14, 13
-    ),
-    cohort_start_date = as.Date(c(
-      rep("2000-01-01", 5), rep("2010-09-05", 5), rep("2006-05-01", 5),
-      rep("2003-03-31", 5), rep("2008-07-02", 5), rep("2000-01-01", 5),
-      rep("2012-09-05", 5), rep("1996-05-01", 5), rep("1989-03-31", 5)
-    )),
-    cohort_end_date = as.Date(c(
-      rep("2000-01-01", 5), rep("2010-09-05", 5), rep("2006-05-01", 5),
-      rep("2003-03-31", 5), rep("2008-07-02", 5), rep("2000-01-01", 5),
-      rep("2012-09-05", 5), rep("1996-05-01", 5), rep("1989-03-31", 5)
-    ))
-  )
-
-  obs <- dplyr::tibble(
-    observation_period_id = 1:20,
-    person_id = 1:20,
-    observation_period_start_date = as.Date("1930-01-01"),
-    observation_period_end_date = as.Date("2025-01-01"),
-    period_type_concept_id = NA
-  )
-
-  cdm <- mockCohortCharacteristics(person = person, observation_period = obs, table = table)
-
-  overlap <- summariseCohortOverlap(cdm$table)
-
-  gtResult1 <- tableCohortOverlap(overlap)
-  expect_true("gt_tbl" %in% class(gtResult1))
-  expect_equal(
-    gtResult1$`_data`$`CDM name`,
-    c("PP_MOCK", rep("", nrow(gtResult1$`_data`) - 1))
-  )
-  expect_equal(unique(gtResult1$`_data`$`Cohort name reference`)[1], "Cohort 1")
-  expect_true(all(c("Cohort 2", "Cohort 3", "Cohort 4") %in%
-    unique(gtResult1$`_data`$`Cohort name comparator`)))
-  expect_false(any(c("Strata name", "Strata level") %in% colnames(gtResult1$`_data`)))
-
-  fxResult1 <- tableCohortOverlap(overlap,
-    type = "flextable",
-    split = character(),
-    header = "group",
-    excludeColumns = c(
-      "result_id", "estimate_type", "strata_name",
-      "strata_level", "additional_name",
-      "additional_level"
-    )
-  )
-  expect_true("flextable" %in% class(fxResult1))
-  expect_true(all(c(
-    "CDM name",
-    "Estimate name",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nIn both cohorts",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nIn both cohorts",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nIn both cohorts",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nIn both cohorts",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nIn both cohorts",
-    "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nOnly in reference cohort",
-    "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nOnly in comparator cohort",
-    "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nIn both cohorts"
-  ) %in%
-    colnames(fxResult1$body$dataset)))
-
-  cdm$table <- cdm$table |>
-    PatientProfiles::addAge(ageGroup = list(c(0, 40), c(41, 100))) |>
-    PatientProfiles::addSex() |>
-    dplyr::compute(name = "table", temporary = FALSE) |>
-    omopgenerics::newCohortTable()
-
-  overlap3 <- summariseCohortOverlap(cdm$table,
-    strata = list("age_group", c("age_group", "sex"))
-  )
-  tibbleResult1 <- tableCohortOverlap(overlap3,
-    type = "tibble",
-    split = character(),
-    header = character()
-  )
-  expect_true(all(c("tbl_df", "tbl", "data.frame") %in% class(tibbleResult1)))
-  expect_true(all(c(
-    "CDM name", "Group name", "Group level", "Strata name", "Strata level", "Estimate name",
-    "Additional name", "Additional level",
-    "[header_level]Only in reference cohort",
-    "[header_level]Only in comparator cohort",
-    "[header_level]In both cohorts"
-  ) %in% colnames(tibbleResult1)))
-
-  gtResult2 <- tableCohortOverlap(overlap3,
-    type = "gt"
-  )
-  expect_true("gt_tbl" %in% class(gtResult2))
-  expect_true(all(c(
-    "CDM name", "Cohort name reference", "Cohort name comparator", "Estimate name",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]Only in reference cohort",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]Only in comparator cohort",
-    "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]In both cohorts",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]Only in reference cohort",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]Only in comparator cohort",
-    "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]In both cohorts",
-    "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
-    "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
-    "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts"
-  ) %in%
-    colnames(gtResult2$`_data`)))
-
-  CDMConnector::cdm_disconnect(cdm)
+  # person <- dplyr::tibble(
+  #   person_id = 1:20,
+  #   gender_concept_id = sample(c(8532, 8507), size = 20, replace = T),
+  #   year_of_birth = runif(n = 20, min = 1950, max = 2000),
+  #   month_of_birth = runif(n = 20, min = 1, max = 12),
+  #   day_of_birth = runif(n = 20, min = 1, max = 28),
+  #   race_concept_id = 0,
+  #   ethnicity_concept_id = 0
+  # )
+  #
+  # table <- dplyr::tibble(
+  #   cohort_definition_id = c(rep(1, 15), rep(2, 10), rep(3, 15), rep(4, 5)),
+  #   subject_id = c(
+  #     20, 5, 10, 12, 4, 15, 2, 1, 5, 10, 5, 8, 13, 4, 10,
+  #     6, 18, 5, 1, 20, 14, 13, 8, 17, 3,
+  #     16, 15, 20, 17, 3, 14, 6, 11, 8, 7, 20, 19, 5, 2, 18,
+  #     5, 12, 3, 14, 13
+  #   ),
+  #   cohort_start_date = as.Date(c(
+  #     rep("2000-01-01", 5), rep("2010-09-05", 5), rep("2006-05-01", 5),
+  #     rep("2003-03-31", 5), rep("2008-07-02", 5), rep("2000-01-01", 5),
+  #     rep("2012-09-05", 5), rep("1996-05-01", 5), rep("1989-03-31", 5)
+  #   )),
+  #   cohort_end_date = as.Date(c(
+  #     rep("2000-01-01", 5), rep("2010-09-05", 5), rep("2006-05-01", 5),
+  #     rep("2003-03-31", 5), rep("2008-07-02", 5), rep("2000-01-01", 5),
+  #     rep("2012-09-05", 5), rep("1996-05-01", 5), rep("1989-03-31", 5)
+  #   ))
+  # )
+  #
+  # obs <- dplyr::tibble(
+  #   observation_period_id = 1:20,
+  #   person_id = 1:20,
+  #   observation_period_start_date = as.Date("1930-01-01"),
+  #   observation_period_end_date = as.Date("2025-01-01"),
+  #   period_type_concept_id = NA
+  # )
+  #
+  # cdm <- mockCohortCharacteristics(
+  #   con = connection(), writeSchema = writeSchema(), person = person,
+  #   observation_period = obs, table = table
+  # )
+  #
+  # overlap <- summariseCohortOverlap(cdm$table)
+  #
+  # gtResult1 <- tableCohortOverlap(overlap)
+  # expect_true("gt_tbl" %in% class(gtResult1))
+  # expect_equal(
+  #   gtResult1$`_data`$`CDM name`,
+  #   c("PP_MOCK", rep("", nrow(gtResult1$`_data`) - 1))
+  # )
+  # expect_equal(unique(gtResult1$`_data`$`Cohort name reference`)[1], "Cohort 1")
+  # expect_true(all(c("Cohort 2", "Cohort 3", "Cohort 4") %in%
+  #   unique(gtResult1$`_data`$`Cohort name comparator`)))
+  # expect_false(any(c("Strata name", "Strata level") %in% colnames(gtResult1$`_data`)))
+  #
+  # fxResult1 <- tableCohortOverlap(overlap,
+  #   type = "flextable",
+  #   split = character(),
+  #   header = "group",
+  #   excludeColumns = c(
+  #     "result_id", "estimate_type", "strata_name",
+  #     "strata_level", "additional_name",
+  #     "additional_level"
+  #   )
+  # )
+  # expect_true("flextable" %in% class(fxResult1))
+  # expect_true(all(c(
+  #   "CDM name",
+  #   "Estimate name",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 2\nIn both cohorts",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 3\nIn both cohorts",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 1 and cohort 4\nIn both cohorts",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 3\nIn both cohorts",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 2 and cohort 4\nIn both cohorts",
+  #   "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nOnly in reference cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nOnly in comparator cohort",
+  #   "Cohort name reference and cohort name comparator\nCohort 3 and cohort 4\nIn both cohorts"
+  # ) %in%
+  #   colnames(fxResult1$body$dataset)))
+  #
+  # cdm$table <- cdm$table |>
+  #   PatientProfiles::addAge(ageGroup = list(c(0, 40), c(41, 100))) |>
+  #   PatientProfiles::addSex() |>
+  #   dplyr::compute(name = "table", temporary = FALSE) |>
+  #   omopgenerics::newCohortTable()
+  #
+  # overlap3 <- summariseCohortOverlap(cdm$table,
+  #   strata = list("age_group", c("age_group", "sex"))
+  # )
+  # tibbleResult1 <- tableCohortOverlap(overlap3,
+  #   type = "tibble",
+  #   split = character(),
+  #   header = character()
+  # )
+  # expect_true(all(c("tbl_df", "tbl", "data.frame") %in% class(tibbleResult1)))
+  # expect_true(all(c(
+  #   "CDM name", "Group name", "Group level", "Strata name", "Strata level", "Estimate name",
+  #   "Additional name", "Additional level",
+  #   "[header_level]Only in reference cohort",
+  #   "[header_level]Only in comparator cohort",
+  #   "[header_level]In both cohorts"
+  # ) %in% colnames(tibbleResult1)))
+  #
+  # gtResult2 <- tableCohortOverlap(overlap3,
+  #   type = "gt"
+  # )
+  # expect_true("gt_tbl" %in% class(gtResult2))
+  # expect_true(all(c(
+  #   "CDM name", "Cohort name reference", "Cohort name comparator", "Estimate name",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]Only in reference cohort",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]Only in comparator cohort",
+  #   "[header]Age group\n[header_level]0 to 40\n[header]Sex\n[header_level]Female\n[header_level]In both cohorts",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]Only in reference cohort",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]Only in comparator cohort",
+  #   "[header]Age group\n[header_level]41 to 100\n[header]Sex\n[header_level]Female\n[header_level]In both cohorts",
+  #   "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]Only in reference cohort",
+  #   "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]Only in comparator cohort",
+  #   "[header]Age group\n[header_level]Overall\n[header]Sex\n[header_level]Overall\n[header_level]In both cohorts"
+  # ) %in%
+  #   colnames(gtResult2$`_data`)))
+  #
+  # mockDisconnect(cdm)
 })
 
 test_that("tableCohortTiming", {
@@ -375,5 +379,5 @@ test_that("tableCohortTiming", {
   #                   "[header]CDM name\n[header_level]PP_MOCK\n[header_level]Cohort name reference and cohort name comparator\n[header_level]Cohort 1 and cohort 3\n[header_level]Overall\n[header_level]Overall") %in%
   #                   colnames(gt3$`_data`)))
   #
-  # CDMConnector::cdm_disconnect(cdm)
+  # mockDisconnect(cdm)
 })
